/*
 * Copyright (c) 2004-2005 by John Schmerge.
 * All rights reserved.
 *
 * $Id: cronfile.h,v 1.8 2005/04/25 03:29:07 john Exp $
 */

#ifndef CRONFILE_H
#define CRONFILE_H 1

/*
 */
enum LogType
{
	LogTypeDevNull,
	LogTypeFileTrunc,
	LogTypeFileAppend,
	LogTypeSyslog,
	LogTypeMail,
	LogTypeTty
};

/*
 */
struct TabOptions
{
	/* This is the uid that jobs in jobList should be run as */
	uid_t uid;

	unsigned char loggingType;

	unsigned char syslogFacility;
	unsigned char syslogPriority;

	char * emailAddress;
	char * logFileName;
};

/*
 */
struct Crontab
{
	/* This is here so that we may keep all crontabs in a linked list */
	struct Crontab * next;

	/* options specified in the crontab */
	struct TabOptions tabOptions;

	/* this allows us to do a quick check as to whether or not the
	 * crontab has changed since the last time we read it
	 */
	time_t lastModificationTime;

	/* the list of jobs contained in the crontab */
	struct Job * jobList;
};


/* ********************************************************************
 */
void checkCrontabs(struct Crontab * systemTab, struct Crontab ** list);

/* ********************************************************************
 */
void destroyTabList(struct Crontab ** list);

#endif

/* ********************************************************************
 * $Log: cronfile.h,v $
 * Revision 1.8  2005/04/25 03:29:07  john
 * Modified the CronFile struct to contained unsigned char's for enum values
 * instead of int's and added support for specifying logfile name.
 *
 * Revision 1.7  2005/04/24 02:33:16  john
 * changed type on logging value to be an int instead of an enum
 *
 * Revision 1.6  2005/03/27 01:19:11  john
 * updated copyright
 *
 * Revision 1.5  2003/02/11 09:16:27  john
 * size-reducing changes; also removed the job input spec
 *
 * Revision 1.4  2003/02/04 10:21:37  john
 * added tty logging type to enumeration
 *
 * Revision 1.3  2003/02/04 07:23:44  john
 * removed the include of job.h from this header
 *
 * Revision 1.2  2003/01/22 07:43:47  john
 * removed typedefs in favor of explicit struct defs, added TabOptions
 * structure, and added enumeration for logging action
 *
 * Revision 1.1.1.1  2002/10/06 06:47:18  john
 * initial import of sources
 *
 */
